# $Id: networking.sh 1035 2010-05-30 18:37:54Z niro $

network_config()
{
	dialog \
		--stdout \
		--colors \
		--title "Network Configuration" \
		--backtitle "${TITLE}" \
		--form "Enter a Hostname:" 10 70 0 \
		"Hostname:" 1 1 "${NETWORK_HOSTNAME}" 1 18 36 0 \
		"  Domain:" 2 1 "${NETWORK_DOMAIN}" 2 18 36 0
}

network_config_select()
{
	dialog \
		--stdout \
		--colors \
		--title "Network Configuration" \
		--backtitle "${TITLE}" \
		--radiolist "Select a network type" \
		10 45 3 \
		dhcp "DHCP based networking" on \
		static "IP based networking" "" \
		none "Disable network support" ""

	return $?
}

network_config_static()
{
	dialog \
		--stdout \
		--colors \
		--title "Network Configuration" \
		--backtitle "${TITLE}" \
		--form "Static network setup:" 12 70 0 \
		"IP-Address:" 1 1 "${NETWORK_IP}" 1 18 36 0 \
		"   Netmask:" 2 1 "${NETWORK_NETMASK}" 2 18 36 0 \
		" Broadcast:" 3 1 "${NETWORK_BROADCAST}" 3 18 36 0 \
		"   Gateway:" 4 1 "${NETWORK_GATEWAY}" 4 18 36 0 \
		"Nameserver:" 5 1 "${NETWORK_NAMESERVER}" 5 18 36 0
}

network_select_nic()
{
	local items=( $(get_hwinfo -d netcard | sed -e "s:\ :_:g") )
	local count=${#items[*]}
	local i

	dialog \
		--stdout \
		--colors \
		--title "Network Configuration" \
		--backtitle "${TITLE}" \
		--radiolist "Select a available NIC" \
		10 60 ${count} \
		$(for (( i=0; i<count; i++ )); do echo "${items[$i]%;*} ${items[$i]#*;} $([[ ${i} -eq 0 ]] && echo on || echo off)"; done)

	return $?
}

check_static_network_config()
{
	# these are a requirement
	if [[ -z ${NETWORK_IP} ]]
	then
		messagebox "Warning" "No IP-Address given!" 10 40
		return 1
	fi

	if [[ -z ${NETWORK_NETMASK} ]]
	then
		messagebox "Warning" "No netmask given!" 10 40
		return 1
	fi

	if [[ -z ${NETWORK_BROADCAST} ]]
	then
		messagebox "Warning" "No broadcast given!" 10 40
		return 1
	fi

	return 0
}

rundialog_network_config()
{
	local NETWORK_CONFIG
	NETWORK_CONFIG=($(network_config))
	case $? in
		-1)	die "Error!" ;;
		255)	die "aborted by user" ;;

		1)
			rundialog_network_config
			;;

		# vars already exported
		0)
			NETWORK_HOSTNAME="${NETWORK_CONFIG[0]}"
			NETWORK_DOMAIN="${NETWORK_CONFIG[1]}"
			if [[ -z ${NETWORK_HOSTNAME} ]]
			then
				messagebox "Warning" "No hostname given." 10 40
				rundialog_network_config
			elif [[ -z ${NETWORK_DOMAIN} ]]
			then
				messagebox "Warning" "No domain given." 10 40
				rundialog_network_config
			fi
			export NETWORK_HOSTNAME
			export NETWORK_DOMAIN
			;;
	esac

	debug "NETWORK_HOSTNAME='${NETWORK_HOSTNAME}'"
	debug "NETWORK_DOMAIN='${NETWORK_DOMAIN}'"
}

rundialog_network_config_select()
{
	NETWORK_METHOD=$(network_config_select)
	case $? in
		-1)	die "Error!" ;;
		255)	die "aborted by user" ;;

		1)
			rundialog_network_config
			rundialog_network_config_select
			;;

		0)	export NETWORK_METHOD
			if [[ ${NETWORK_METHOD} = none ]]
			then
				export NETWORK_METHOD="none"
				messagebox "Warning" "Magellan needs network support for further installations.\nOnly a very basic system get installed.\nTo use more packages, you have to setup your networking manually." 10 70
			else
				# want networking, run nic selection
				rundialog_network_select_nic

				if [[ ${NETWORK_METHOD} = static ]]
				then
					# run static config dialog
					rundialog_network_config_static
				fi
			fi
			;;
	esac

	debug "NETWORK_METHOD='${NETWORK_METHOD}'"
}

rundialog_network_config_static()
{
	local NETWORK_CONFIG
	NETWORK_CONFIG=($(network_config_static))
	case $? in
		-1)	die "Error!" ;;
		255)	die "aborted by user" ;;

		1)
			rundialog_network_select_nic
			rundialog_network_config_static
			;;

		0)
			NETWORK_IP="${NETWORK_CONFIG[0]}"
			NETWORK_NETMASK="${NETWORK_CONFIG[1]}"
			NETWORK_BROADCAST="${NETWORK_CONFIG[2]}"
			NETWORK_GATEWAY="${NETWORK_CONFIG[3]}"
			NETWORK_NAMESERVER="${NETWORK_CONFIG[4]}"
			if ! check_static_network_config
			then
				rundialog_network_config_static
			fi
			export NETWORK_IP
			export NETWORK_NETMASK
			export NETWORK_BROADCAST
			export NETWORK_GATEWAY
			export NETWORK_NAMESERVER
			;;
	esac

	debug "NETWORK_IP='${NETWORK_IP}'"
	debug "NETWORK_NETMASK='${NETWORK_NETMASK}'"
	debug "NETWORK_BROADCAST='${NETWORK_BROADCAST}'"
	debug "NETWORK_GATEWAY='${NETWORK_GATEWAY}'"
	debug "NETWORK_NAMESERVER='${NETWORK_NAMESERVER}'"
}

rundialog_network_select_nic()
{
	NETWORK_NIC=$(network_select_nic)
	case $? in
		-1)	die "Error!" ;;
		255)	die "aborted by user" ;;

		1)
			rundialog_network_config_select
			rundialog_network_select_nic
			;;

		0)	export NETWORK_NIC ;;
	esac

	debug "NETWORK_NIC='${NETWORK_NIC}'"
}

main_networking()
{
	rundialog_network_config
	rundialog_network_config_select
}
